clc; clf;

%% OPTIMISED STEADY STATE VARIABLES
I_s = 4.9138;
T_s = 350.8770;
yAo_s = 0.4830;
Fin_s = 1.6905e-8;

%% FORCING FREQUENCY RANGE
f1 = logspace(-6,2,500) ; % rad/s

%% OPTIMIZATION OF FORCING AMPLITUDES AND PHASE DIFFERENCE FOR THE SIMULTANEOUS CHANGE

%      F      I      fi
ub = [0.5     1      2*pi()] ;
lb = [0       0      0     ] ;
nvars = 3 ;

options1 = optimoptions('ga'     ,'Display','off') ;
options2 = optimoptions('fmincon','Display','off') ;

[Amp_1, Amp_2, fi] = deal(zeros(4,length(f1))) ;


for i = 1:length(f1)

% Global
% Otimisation, minimising simultaneous molar flow out    
x = ga(@(x)ObjFun(x, f1(1,i), I_s, T_s, yAo_s, Fin_s), nvars,[],[],[],[],lb,ub,[],options1) ;

Amp_1(1,i) = x(1) ;
Amp_2(1,i) = x(2) ;
fi   (1,i) = x(3) ;

% Otimisation, maximising simultaneous conversion  
x = ga(@(x)ObjFun1(x, f1(1,i), I_s, T_s, yAo_s, Fin_s),nvars,[],[],[],[],lb,ub,[],options1) ;

Amp_1(2,i) = x(1) ;
Amp_2(2,i) = x(2) ;
fi   (2,i) = x(3) ;

% Local
ig1 = [Amp_1(1,i) , Amp_2(1,i) , fi(1,i)] ;
ig2 = [Amp_1(2,i) , Amp_2(2,i) , fi(2,i)] ;

% Otimisation, minimising simultaneous molar flow out    
x = fmincon(@(x)ObjFun(x, f1(1,i), I_s, T_s, yAo_s, Fin_s), ig1,[],[],[],[],lb,ub,[],options2) ;

Amp_1(3,i) = x(1) ;
Amp_2(3,i) = x(2) ;
fi   (3,i) = x(3) ;

% Otimisation, maximising simultaneous conversion  
x = fmincon(@(x)ObjFun1(x, f1(1,i), I_s, T_s, yAo_s, Fin_s),ig2,[],[],[],[],lb,ub,[],options2) ;

Amp_1(4,i) = x(1) ;
Amp_2(4,i) = x(2) ;
fi   (4,i) = x(3) ;
end

%% PLUGGING OPTIMISED VARIABLES INTO NFRF

[fG2aI10, fG2aII10, fG2star10, Conv_I, Conv_II, Conv_III, Conv_ss, MF_A_in, MF_out_I, MF_out_II, MF_out_III, MF_out_ss, MF_A_III_mean]...
= deal(zeros(2,length(f1)));

for i=1:2  
    
[fG2aI10(i,:), fG2aII10(i,:), fG2star10(i,:), Conv_I(i,:), Conv_II(i,:), Conv_III(i,:), Conv_ss(i,:), MF_A_in(i,:), MF_out_I(i,:), MF_out_II(i,:), MF_out_III(i,:), MF_out_ss, MF_A_III_mean(i,:)]...
= combination3_sims(f1, Amp_1(i+2,:), Amp_2(i+2,:), fi(i+2,:), I_s, T_s, yAo_s, Fin_s) ;

end
%% TABLE 


%% DIAGRAMS

figure (1)
subplot(3,1,1)
semilogx(f1,fG2aI10(1,:),'k','LineWidth',2)
hold on
semilogx(f1,fG2aI10(2,:),'r','LineWidth',2)
legend('Molar Flow Optimised', 'Conversion Optimised')
title('ASO FRF Inlet Flow Rate')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{F_i_n}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,2)
semilogx(f1,fG2aII10(1,:),'k','LineWidth',2)
hold on
semilogx(f1,fG2aII10(2,:),'r','LineWidth',2)
title('ASO FRF Light Intensity')
legend('Molar Flow Optimised', 'Conversion Optimised')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{I}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,3)
semilogx(f1,fG2star10(1,:),'k','LineWidth',2)
hold on
semilogx(f1,fG2star10(2,:),'r','LineWidth',2)
legend('Molar Flow Optimised', 'Conversion Optimised')
title('ASO Cross-Term Flow and Light Intensity')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)^*_{F_in, I}(\omega,-\omega)}, /')
box on
grid

figure (2)
subplot(3,1,1)
semilogx(f1,Conv_I(1,:),'k','LineWidth',2)
hold on
semilogx(f1,Conv_I(2,:),'r','LineWidth',2)
semilogx(f1,Conv_ss,'--','LineWidth',2)
legend('Periodic, Molar Flow Optimised','Periodic, Conversion Optimised', 'Steady State')
title('Flow Rate Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,2)
semilogx(f1,Conv_II(1,:),'k','LineWidth',2)
hold on
semilogx(f1,Conv_II(2,:),'r','LineWidth',2)
semilogx(f1,Conv_ss,'--','LineWidth',2)
legend('Periodic, Molar Flow Optimised','Periodic, Conversion Optimised', 'Steady State')
title('Light Intensity Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,3)
semilogx(f1,Conv_III(1,:),'k','LineWidth',2)
hold on
semilogx(f1,Conv_III(2,:),'r','LineWidth',2)
semilogx(f1,Conv_ss,'--','LineWidth',2)
legend('Periodic, Molar Flow Optimised','Periodic, Conversion Optimised', 'Steady State')
title('Combined Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid

figure (3)
subplot(3,1,1)
semilogx(f1,fi(1,:),'k','LineWidth',2)
hold on
semilogx(f1,fi(2,:),'r','LineWidth',2)
legend('Molar Flow Optimised', 'Conversion Optimised')
title('Optimal Phase Difference')
xlabel('frequency, rad/s')
ylabel('Phase [rad]')
box on
grid
subplot(3,1,2)
semilogx(f1, Amp_1(1,:)*100, 'k', 'LineWidth',2)
hold on
semilogx(f1, Amp_2(1,:)*100, 'r', 'LineWidth',2)
legend('Flow Amplitude', 'Light Intensity Amplitude')
title('Optimal Amplitudes for Molar Flow Out Optimisation')
xlabel('frequency, rad/s')
ylabel('Amplitude, %')
box on
grid
subplot(3,1,3)
semilogx(f1, Amp_1(2,:)*100, 'k', 'LineWidth',2)
hold on
semilogx(f1, Amp_2(2,:)*100, 'r', 'LineWidth',2)
legend('Flow Amplitude', 'Light Intensity Amplitude')
title('Optimal Amplitude for Conversion Optimisation')
xlabel('frequency, rad/s')
ylabel('Amplitude, %')
box on
grid

figure (4)
semilogx(f1, MF_out_III(1,:), 'k', 'linewidth', 2)
hold on
semilogx(f1, MF_out_III(2,:), 'r', 'linewidth', 2)
legend('Molar Flow Optimised', 'Conversion Optimised')
title('Molar Flow Out')
xlabel('frequency, rad/s')
ylabel('Molar Flow Out, mol/s')

