clc; clf;


%% OPTIMISED STEADY STATE VARIABLES

% I_s = 4.9138;
% T_s = 350.8770;
% yAo_s = 0.4830;
% Fin_s = 1.6905e-8;
load('SSVARS') ;
pstn    = find(Conv_A>50 & Conv_A<70) ;
pstnmax = find(max(Conv_A(pstn))) ;
pstnmin = find(min(Conv_A(pstn))) ;
I_s = I(pstn) ;
T_s = T(pstn) ;
yAo_s = yAo(pstn) ;
Fin_s = Fin(pstn) ;

%% FORCING FREQUENCY RANGE
f1 = logspace(-6,2,500) ; % rad/s

%% OPTIMIZATION OF FORCING AMPLITUDES AND PHASE DIFFERENCE FOR THE SIMULTANEOUS CHANGE

%     F       I      fi
%     Amp_1   Amp_2
ub = [0.5     1      2*pi()] ;
lb = [0       0      0     ] ;
nvars = 3 ;

options1 = optimoptions('ga'     ,'Display','off') ;
options2 = optimoptions('fmincon','Display','off') ;

[Amp_fg, Amp_cg, fi_fg, fi_cg] = deal(zeros(  length(I_s),length(f1))) ;
[Amp_1, Amp_2, fi]             = deal(zeros(2*length(I_s),length(f1))) ;

for j = 1:length(I_s)

    % Global
    % Otimisation, minimising simultaneous molar flow out    
    for i = 1:length(f1)
    x1 = ga(@(x1)ObjFun(x1, f1(1,i), I_s(j,1), T_s(j,1), yAo_s(j,1), Fin_s(j,1)), nvars,[],[],[],[],lb,ub,[],options1) ;

    Amp_fg(j,i) = x1(1) ;
    Amp_fg(j,i) = x1(2) ;
    fi_fg (j,i) = x1(3) ;

    % Otimisation, maximising simultaneous conversion  
    x2 = ga(@(x2)ObjFun11(x2, f1(1,i), I_s(j,1), T_s(j,1), yAo_s(j,1), Fin_s(j,1)),nvars,[],[],[],[],lb,ub,[],options1) ;

    Amp_cg(j,i) = x2(1) ;
    Amp_cg(j,i) = x2(2) ;
    fi_cg (j,i) = x2(3) ;

    % Local
    ig1 = [Amp_fg(j,i) , Amp_fg(j,i) , fi_fg(j,i)] ;
    ig2 = [Amp_cg(j,i) , Amp_cg(j,i) , fi_cg(j,i)] ;

    % Otimisation, minimising simultaneous molar flow out    
    x1 = fmincon(@(x1)ObjFun(x1, f1(1,i), I_s(j,1), T_s(j,1), yAo_s(j,1), Fin_s(j,1)), ig1,[],[],[],[],lb,ub,[],options2) ;

    Amp_1(j,i) = x1(1) ;
    Amp_2(j,i) = x1(2) ;
    fi   (j,i) = x1(3) ;

    % Otimisation, maximising simultaneous conversion  
    x2 = fmincon(@(x2)ObjFun11(x2, f1(1,i), I_s(j,1), T_s(j,1), yAo_s(j,1), Fin_s(j,1)),ig2,[],[],[],[],lb,ub,[],options2) ;

    Amp_1(j+length(I_s),i) = x2(1) ;
    Amp_2(j+length(I_s),i) = x2(2) ;
    fi   (j+length(I_s),i) = x2(3) ;
    end

end

%% PLUGGING OPTIMISED VARIABLES INTO NFRF

[fG2aI10, fG2aII10, fG2star10, Conv_I, Conv_II, Conv_III, Conv_ss, MF_A_in, MF_out_I, MF_out_II, MF_out_III, MF_out_ss, MF_A_III_mean]...
= deal(zeros(length(I_s),length(f1)));
sz = size(Amp_1) ;

for i=1:length(I_s)
 
[fG2aI10(i,:), fG2aII10(i,:), fG2star10(i,:), Conv_I(i,:), Conv_II(i,:), Conv_III(i,:), Conv_ss(i,:), MF_A_in(i,:), MF_out_I(i,:), MF_out_II(i,:), MF_out_III(i,:), MF_out_ss(i,:), MF_A_III_mean(i,:)]...
= combination3_sims(f1, Amp_1(i,:), Amp_2(i,:), fi(i,:), I_s(i,1), T_s(i,1), yAo_s(i,1), Fin_s(i,1)) ;

[fG2aI10(i+length(I_s),:), fG2aII10(i+length(I_s),:), fG2star10(i+length(I_s),:), Conv_I(i+length(I_s),:), Conv_II(i+length(I_s),:), Conv_III(i+length(I_s),:),...
 Conv_ss(i+length(I_s),:), MF_A_in(i+length(I_s),:), MF_out_I(i+length(I_s),:), MF_out_II(i+length(I_s),:), MF_out_III(i+length(I_s),:), MF_out_ss(i+length(I_s),:), MF_A_III_mean(i+length(I_s),:)]...
= combination3_sims(f1, Amp_1(i+length(I_s),:), Amp_2(i+length(I_s),:), fi(i+length(I_s),:), I_s(i,1), T_s(i,1), yAo_s(i,1), Fin_s(i,1)) ;

end

% %% NON OPTIMISED FOR COMPARISON
% 
% Amp_1NO = 0.5;
% Amp_2NO = 0.5;
% 
% [fG2aI10NO, fG2aII10NO, fG2star10NO, Conv_INO, Conv_IINO, Conv_IIINO, Conv_ssNO, MF_A_inNO, MF_out_INO, MF_out_IINO, MF_out_IIINO, MF_out_ss, MF_A_III_meanNO]...
% = combination1_sims(f1, Amp_1NO, Amp_2NO, I_s, T_s, yAo_s, Fin_s) ;

%% TABLES

[TAB1, TAB2, TAB3] = TABLES(Conv_III, Conv_ss, MF_A_in, MF_out_III, I_s, T_s, yAo_s, Fin_s)

%% DIAGRAMS

figure (1)
subplot(3,2,1)
semilogx(f1,fG2aI10(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,fG2aI10(2,:),'r','LineWidth',2)
% legend('Molar Flow Optimised', 'Conversion Optimised')
title('ASO FRF Inlet Flow Rate, Max Conversion')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{F_i_n}(\omega,-\omega)}, /')
box on
grid
subplot(3,2,3)
semilogx(f1,fG2aII10(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,fG2aII10(2,:),'r','LineWidth',2)
title('ASO FRF Light Intensity, Max Conversion')
% legend('Molar Flow Optimised', 'Conversion Optimised')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{I}(\omega,-\omega)}, /')
box on
grid
subplot(3,2,5)
semilogx(f1,fG2star10(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,fG2star10(2,:),'r','LineWidth',2)
% legend('Molar Flow Optimised', 'Conversion Optimised')
title('ASO Cross-Term Flow and Light Intensity, Max Conversion')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)^*_{F_in, I}(\omega,-\omega)}, /')
box on
grid

subplot(3,2,2)
semilogx(f1,Conv_I(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,Conv_I(2,:),'r','LineWidth',2)
semilogx(f1,Conv_ss(Rindexmaxdiff,:),'--','LineWidth',2)
legend('Periodic', 'Steady State')
title('Flow Rate Modulation, Max Conversion')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,2,4)
semilogx(f1,Conv_II(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,Conv_II(2,:),'r','LineWidth',2)
semilogx(f1,Conv_ss(Rindexmaxdiff,:),'--','LineWidth',2)
legend('Periodic', 'Steady State')
title('Light Intensity Modulation, Max Conversion')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,2,6)
semilogx(f1,Conv_III(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,Conv_III(2,:),'r','LineWidth',2)
semilogx(f1,Conv_ss(Rindexmaxdiff,:),'--','LineWidth',2)
legend('Periodic', 'Steady State')
title('Combined Modulation, Max Conversion')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid

figure (2)
subplot(3,1,1)
semilogx(f1,fi(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,fi(2,:),'r','LineWidth',2)
% legend('Molar Flow Optimised', 'Conversion Optimised')
title('Optimal Phase Difference, Max Conversion')
xlabel('frequency, rad/s')
ylabel('Phase [rad]')
box on
grid
subplot(3,1,2)
semilogx(f1, Amp_1(Rindexmaxdiff,:)*100, 'k', 'LineWidth',2)
hold on
semilogx(f1, Amp_2(Rindexmaxdiff,:)*100, 'r', 'LineWidth',2)
legend('Flow Amplitude', 'Light Intensity Amplitude')
title('Optimal Amplitudes, Max Conversion')
xlabel('frequency, rad/s')
ylabel('Amplitude, %')
box on
grid
subplot(3,1,3)
semilogx(f1, Amp_1(2,:)*100, 'k', 'LineWidth',2)
hold on
semilogx(f1, Amp_2(2,:)*100, 'r', 'LineWidth',2)
legend('Flow Amplitude', 'Molar Fraction Amplitude')
title('DONT USE')
xlabel('frequency, rad/s')
ylabel('Amplitude, %')
box on
grid

Rindexmaxdiff = RindexmaxMF ; % Swapping to max flow in
figure (3)
subplot(3,2,1)
semilogx(f1,fG2aI10(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,fG2aI10(2,:),'r','LineWidth',2)
% legend('Molar Flow Optimised', 'Conversion Optimised')
title('ASO FRF Inlet Flow Rate, Max Flow in')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{F_i_n}(\omega,-\omega)}, /')
box on
grid
subplot(3,2,3)
semilogx(f1,fG2aII10(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,fG2aII10(2,:),'r','LineWidth',2)
title('ASO FRF Light Intensity, Max Flow in')
% legend('Molar Flow Optimised', 'Conversion Optimised')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{I}(\omega,-\omega)}, /')
box on
grid
subplot(3,2,5)
semilogx(f1,fG2star10(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,fG2star10(2,:),'r','LineWidth',2)
% legend('Molar Flow Optimised', 'Conversion Optimised')
title('ASO Cross-Term Flow and Light Intensity, Max Flow in')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)^*_{F_in, I}(\omega,-\omega)}, /')
box on
grid

subplot(3,2,2)
semilogx(f1,Conv_I(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,Conv_I(2,:),'r','LineWidth',2)
semilogx(f1,Conv_ss(Rindexmaxdiff,:),'--','LineWidth',2)
legend('Periodic', 'Steady State')
title('Flow Rate Modulation, Max Flow in')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,2,4)
semilogx(f1,Conv_II(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,Conv_II(2,:),'r','LineWidth',2)
semilogx(f1,Conv_ss(Rindexmaxdiff,:),'--','LineWidth',2)
legend('Periodic', 'Steady State')
title('Light Intensity Modulation, Max Flow in')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,2,6)
semilogx(f1,Conv_III(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,Conv_III(2,:),'r','LineWidth',2)
semilogx(f1,Conv_ss(Rindexmaxdiff,:),'--','LineWidth',2)
legend('Periodic', 'Steady State')
title('Combined Modulation, Max Flow in')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid

figure (4)
subplot(3,1,1)
semilogx(f1,fi(Rindexmaxdiff,:),'k','LineWidth',2)
hold on
% semilogx(f1,fi(2,:),'r','LineWidth',2)
% legend('Molar Flow Optimised', 'Conversion Optimised')
title('Optimal Phase Difference, Max Flow in')
xlabel('frequency, rad/s')
ylabel('Phase [rad]')
box on
grid
subplot(3,1,2)
semilogx(f1, Amp_1(Rindexmaxdiff,:)*100, 'k', 'LineWidth',2)
hold on
semilogx(f1, Amp_2(Rindexmaxdiff,:)*100, 'r', 'LineWidth',2)
legend('Flow Amplitude', 'Light Intensity Amplitude, Max Flow in')
title('Optimal Amplitudes')
xlabel('frequency, rad/s')
ylabel('Amplitude, %')
box on
grid
subplot(3,1,3)
semilogx(f1, Amp_1(2,:)*100, 'k', 'LineWidth',2)
hold on
semilogx(f1, Amp_2(2,:)*100, 'r', 'LineWidth',2)
legend('Flow Amplitude', 'Molar Fraction Amplitude')
title('DONT USE')
xlabel('frequency, rad/s')
ylabel('Amplitude, %')
box on
grid

% figure (3)
% semilogx(f1, MF_out_III(Rindexmaxdiff,:), 'k', 'linewidth', 2)
% hold on
% % semilogx(f1, MF_out_III(2,:), 'r', 'linewidth', 2)
% legend('Molar Flow Optimised', 'Conversion Optimised')
% title('Molar Flow Out')
% xlabel('frequency, rad/s')
% ylabel('Molar Flow Out, mol/s')

% %% GA THEN FMINCON DIAGRAMS
% if Rindexmaxdiff==Rindexmaxdiff
%     
% elseif  Rindexmaxdiff~=Rindexmaxdiff
% figure (4)
% subplot(3,2,1)
% semilogx(f1,fG2aI10(Rindexmaxdiff,:),'k','LineWidth',2)
% hold on
% % semilogx(f1,fG2aI10(2,:),'r','LineWidth',2)
% legend('Molar Flow Optimised', 'Conversion Optimised')
% title('ASO FRF Inlet Flow Rate')
% xlabel('frequency, rad/s')
% ylabel('\it{G^(^2^)_{F_i_n}(\omega,-\omega)}, /')
% box on
% grid
% subplot(3,2,3)
% semilogx(f1,fG2aII10(Rindexmaxdiff,:),'k','LineWidth',2)
% hold on
% % semilogx(f1,fG2aII10(2,:),'r','LineWidth',2)
% title('ASO FRF Molar Fraction')
% legend('Molar Flow Optimised', 'Conversion Optimised')
% xlabel('frequency, rad/s')
% ylabel('\it{G^(^2^)_{I}(\omega,-\omega)}, /')
% box on
% grid
% subplot(3,2,5)
% semilogx(f1,fG2star10(Rindexmaxdiff,:),'k','LineWidth',2)
% hold on
% % semilogx(f1,fG2star10(2,:),'r','LineWidth',2)
% legend('Molar Flow Optimised', 'Conversion Optimised')
% title('ASO Cross-Term Flow and Molar Fraction')
% xlabel('frequency, rad/s')
% ylabel('\it{G^(^2^)^*_{F_in, I}(\omega,-\omega)}, /')
% box on
% grid
% 
% subplot(3,2,2)
% semilogx(f1,Conv_I(Rindexmaxdiff,:),'k','LineWidth',2)
% hold on
% % semilogx(f1,Conv_I(2,:),'r','LineWidth',2)
% semilogx(f1,Conv_ss(Rindexmaxdiff,:),'--','LineWidth',2)
% legend('Periodic, Molar Flow Optimised','Periodic, Conversion Optimised', 'Steady State')
% title('Flow Rate Modulation')
% xlabel('frequency, rad/s')
% ylabel('Conversion')
% box on
% grid
% subplot(3,2,4)
% semilogx(f1,Conv_II(Rindexmaxdiff,:),'k','LineWidth',2)
% hold on
% % semilogx(f1,Conv_II(2,:),'r','LineWidth',2)
% semilogx(f1,Conv_ss(Rindexmaxdiff,:),'--','LineWidth',2)
% legend('Periodic, Molar Flow Optimised','Periodic, Conversion Optimised', 'Steady State')
% title('Molar Fraction Modulation')
% xlabel('frequency, rad/s')
% ylabel('Conversion')
% box on
% grid
% subplot(3,2,6)
% semilogx(f1,Conv_III(Rindexmaxdiff,:),'k','LineWidth',2)
% hold on
% % semilogx(f1,Conv_III(2,:),'r','LineWidth',2)
% semilogx(f1,Conv_ss(Rindexmaxdiff,:),'--','LineWidth',2)
% legend('Periodic, Molar Flow Optimised','Periodic, Conversion Optimised', 'Steady State')
% title('Combined Modulation')
% xlabel('frequency, rad/s')
% ylabel('Conversion')
% box on
% grid
% 
% figure (5)
% subplot(2,1,1)
% semilogx(f1,fi(Rindexmaxdiff,:),'k','LineWidth',2)
% hold on
% % semilogx(f1,fi(2,:),'r','LineWidth',2)
% legend('Molar Flow Optimised', 'Conversion Optimised')
% title('Optimal Phase Difference')
% xlabel('frequency, rad/s')
% ylabel('Phase [rad]')
% box on
% grid
% subplot(2,1,2)
% semilogx(f1, Amp_1(Rindexmaxdiff,:)*100, 'k', 'LineWidth',2)
% hold on
% semilogx(f1, Amp_2(Rindexmaxdiff,:)*100, 'r', 'LineWidth',2)
% legend('Flow Amplitude', 'Molar Fraction Amplitude')
% title('Optimal Amplitudes for Molar Flow Out Optimisation')
% xlabel('frequency, rad/s')
% ylabel('Amplitude, %')
% box on
% grid
% % subplot(3,1,3)
% % semilogx(f1, Amp_1(2,:)*100, 'k', 'LineWidth',2)
% % hold on
% % semilogx(f1, Amp_2(2,:)*100, 'r', 'LineWidth',2)
% % legend('Flow Amplitude', 'Molar Fraction Amplitude')
% % title('Optimal Amplitude for Conversion Optimisation')
% % xlabel('frequency, rad/s')
% % ylabel('Amplitude, %')
% % box on
% % grid
% 
% figure (6)
% semilogx(f1, MF_out_III(Rindexmaxdiff,:), 'k', 'linewidth', 2)
% hold on
% % semilogx(f1, MF_out_III(2,:), 'r', 'linewidth', 2)
% legend('Molar Flow Optimised', 'Conversion Optimised')
% title('Molar Flow Out')
% xlabel('frequency, rad/s')
% ylabel('Molar Flow Out, mol/s')
% 
% end
% 
function [TAB1, TAB2, TAB3] = TABLES(Conv_III, Conv_ss, MF_A_in, MF_out_III, I_s, T_s, yAo_s, Fin_s)
%% TABLE 
%  minmf = min(real(MF_out_III), [], 2) ;
% [minMF,Rindexmaxdiff] = min(minmf) ;
% 
%  maxcv = max(real(Conv_III), [], 2) ;
% [maxCV, Rindexmaxdiff] = max(maxcv) ;

% Max difference in conversion, simultaneous minus SS
 diffCV                    = Conv_III - Conv_ss ;
[maxdiff,   Cindexmaxdiff] = max(diffCV,[],2) ;
[MAXDIFFCV, Rindexmaxdiff] = max(maxdiff) ;

% Max MF of acid in
[maxmfin, CindexmaxMF] = max(MF_A_in, [], 2) ;
[maxMFin, RindexmaxMF] = max(maxmfin) ;

% Min MF of acid out
[minmfout, CindexminMF] = min(MF_out_III, [], 2) ;
[minMFout, RindexminMF] = min(minmfout) ;



% Input Values
if Rindexmaxdiff>length(I_s)
    
LightIntensity1 = I_s(Rindexmaxdiff-length(I_s),1) ;
Temperature1    = T_s(Rindexmaxdiff-length(I_s),1) ;
MolarFraction1  = yAo_s(Rindexmaxdiff-length(I_s),1) ;
FlowIn1         = Fin_s(Rindexmaxdiff-length(I_s),1) ;

    elseif Rindexmaxdiff<=length(I_s)

    LightIntensity1 = I_s(Rindexmaxdiff,1) ;
    Temperature1    = T_s(Rindexmaxdiff,1) ;
    MolarFraction1  = yAo_s(Rindexmaxdiff,1) ;
    FlowIn1         = Fin_s(Rindexmaxdiff,1) ;

end

if RindexmaxMF>length(I_s)
    
LightIntensity2 = I_s(RindexmaxMF-length(I_s),1) ;
Temperature2    = T_s(RindexmaxMF-length(I_s),1) ;
MolarFraction2  = yAo_s(RindexmaxMF-length(I_s),1) ;
FlowIn2         = Fin_s(RindexmaxMF-length(I_s),1) ;

    elseif RindexmaxMF<=length(I_s)

    LightIntensity2 = I_s(RindexmaxMF,1) ;
    Temperature2    = T_s(RindexmaxMF,1) ;
    MolarFraction2  = yAo_s(RindexmaxMF,1) ;
    FlowIn2         = Fin_s(RindexmaxMF,1) ;

end

if RindexminMF>length(I_s)
    
LightIntensity3 = I_s(RindexminMF-length(I_s),1) ;
Temperature3    = T_s(RindexminMF-length(I_s),1) ;
MolarFraction3  = yAo_s(RindexminMF-length(I_s),1) ;
FlowIn3         = Fin_s(RindexminMF-length(I_s),1) ;

    elseif RindexminMF<=length(I_s)

    LightIntensity3 = I_s(RindexminMF,1) ;
    Temperature3    = T_s(RindexminMF,1) ;
    MolarFraction3  = yAo_s(RindexminMF,1) ;
    FlowIn3         = Fin_s(RindexminMF,1) ;

end

ConvSSCVmax   = Conv_ss(Rindexmaxdiff,CindexmaxMF(Rindexmaxdiff)) ;
Conv_IIICVmax = real(Conv_III(Rindexmaxdiff,CindexmaxMF(Rindexmaxdiff))) ;

ConvSSMFmax   = Conv_ss(RindexmaxMF,CindexmaxMF(RindexmaxMF)) ;
Conv_IIIMFmax = real(Conv_III(RindexmaxMF,CindexmaxMF(RindexmaxMF))) ;

ConvSSMFmin   = Conv_ss(RindexminMF,CindexmaxMF(RindexminMF)) ;
Conv_IIIMFmin = real(Conv_III(RindexminMF,CindexmaxMF(RindexminMF))) ;

disp('Max Conversion Inputs')
TAB1 = table(LightIntensity1, Temperature1,MolarFraction1, FlowIn1, ConvSSCVmax, Conv_IIICVmax, Rindexmaxdiff)
disp('Max Flow In Inputs')
TAB2 = table(LightIntensity2, Temperature2,MolarFraction2, FlowIn2, ConvSSMFmax, Conv_IIIMFmax, RindexmaxMF)
disp('Min Flow Out Inputs')
TAB3 = table(LightIntensity3, Temperature3,MolarFraction3, FlowIn3, ConvSSMFmin, Conv_IIIMFmin, RindexminMF)

end