function [of] = ObjFun(x2, f1, I_s, T_in, y_A_in, F_in) 


%% OPERATING PARAMETER AND CONSTANT VALUES

% 
% I_s = 4.9689 ;
% T_in = 351.1617 ;
% y_A_in = 0.4877 ;
% F_in = 1.9029e-8 ;

Amp_1 = x2(1) ;
Amp_2 = x2(2) ;
fi    = x2(3) ;

T_s = T_in ; % SS temperature inside the reactor same as the inlet temperature

% CONSTANTS

n_tot = 0.0537 ;
I_o = 1.6 ;
p = 101325 ;
V = 2e-4 ;

Ea_D1 = 113100 ;
Ea_D2 = 20920 ;
Ea_R = 8480 ;


k_A1 = 1.503 ;
k_A2 = 1.5e-5 ;
k_A3 = 32430 ;
k_D1 = 1e13 ;
k_D2 = 2.05 ;
k_R = 0.24 ;

R = 8.314 ;


%% FORCING AMPLITUDE USED IN THE PRELIMINARY SIMULATION 

A1 = Amp_1 ;  % Flow in
A2 = Amp_2 ;  % Light Intensity

%% STEADY-STATE VALUES COMPUTATION WITH EQUATIONS SUPPLIED BY TOM ELLWOOD

y_N_in = 1 - y_A_in;

k_ads_s =   k_A1 + k_A2 .* exp (  k_A3 ./ R ./ T_in);
k_des_s =   k_D1 .* exp (- Ea_D1 ./ R ./ T_in) + k_D2 .* exp (- Ea_D2  ./ R ./ T_in);
n_R_s   =   n_tot .* exp (- Ea_R  ./ R ./ T_in) .* (I_s ./ I_o).^ 0.3; 

y_A_s   =  -(F_in*R*T_in*k_des_s*n_tot - (F_in^2*R^2*T_in^2*k_R^2*n_R_s^2 + 2*F_in^2*R^2*T_in^2*k_des_s*k_R*n_R_s*n_tot + F_in^2*R^2*T_in^2*k_des_s^2*n_tot^2 + 2*F_in*R^2*T_in*T_in*V*k_ads_s*k_R^2*n_R_s^2*n_tot + 2*F_in*R^2*T_in*T_in*V*k_ads_s*k_des_s*k_R*n_R_s*n_tot^2 + R^2*T_in^2*V^2*k_ads_s^2*k_R^2*n_R_s^2*n_tot^2 ...
            + 2*F_in^2*p*R*T_in*k_ads_s*k_R*n_R_s*n_tot*y_A_in + 4*F_in*R^2*T_in*T_in*V*k_ads_s*k_R^2*n_R_s^2*n_tot*y_A_in + 2*F_in^2*p*R*T_in*k_ads_s*k_des_s*n_tot^2*y_A_in + 4*F_in*R^2*T_in*T_in*V*k_ads_s*k_des_s*k_R*n_R_s*n_tot^2*y_A_in - 2*F_in*p*R*T_in*V*k_ads_s^2*k_R*n_R_s*n_tot^2*y_A_in + F_in^2*p^2*k_ads_s^2*n_tot^2*y_A_in^2)^(1/2) + F_in*R*T_in*k_R*n_R_s - F_in*p*k_ads_s*n_tot*y_A_in + R*T_in*V*k_ads_s*k_R*n_R_s*n_tot)/(2*(F_in*p*k_ads_s*n_tot + R*T_in*V*k_ads_s*k_R*n_R_s*n_tot));
 
theta_A_s = (p*k_ads_s*y_A_s)/(R*T_in*(k_des_s + (k_R*n_R_s)/n_tot + (p*k_ads_s*y_A_s)/(R*T_in)));
F_out_s   = V*(T_in./T_in .* F_in./V - k_ads_s .*n_tot * (1-theta_A_s) .* y_A_s + R* T_in/p * k_des_s .* theta_A_s * n_tot + 2*R.*T_in/p * k_R   .* n_R_s    .* theta_A_s   );
y_H2_s    = (R*T_in*V*k_R*n_R_s*theta_A_s)/(F_out_s*p);
y_CO2_s   = (R*T_in*V*k_R*n_R_s*theta_A_s)/(F_out_s*p);

MF_A_in = F_in    * y_A_in *p / R ./T_in ;
MF_A_s  = F_out_s * y_A_s  *p / R /T_s ;

%% FRFs COMPUTATION
         
fG1_I1 = G1_I1(F_in,F_out_s,R,T_s,T_in,T_in,V,f1,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,p,theta_A_s,y_A_s,y_A_in) ;
fG1_I5 = G1_I5(F_in,F_out_s,R,T_s,T_in,T_in,V,f1,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,p,theta_A_s,y_A_s,y_A_in) ;
fG1_I6 = G1_I6(F_in,F_out_s,R,T_s,T_in,T_in,V,f1,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,p,theta_A_s,y_A_s,y_A_in) ;
fG1_I7 = G1_I7 ;
fG1_I8 = G1_I8 ;
fG1_I9 = G1_I9 ;
fG1k_I1 = conj(fG1_I1) ;
fG1k_I5 = conj(fG1_I5) ;
fG1k_I6 = conj(fG1_I6) ;
fG1k_I7 = conj(fG1_I7) ;
fG1k_I8 = conj(fG1_I8) ;
fG1k_I9 = conj(fG1_I9) ;
fG1_II1 = G1_II1(Ea_R,F_out_s,I_o,I_s,R,T_s,V,f1,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ;
fG1_II5 = G1_II5(Ea_R,F_out_s,I_o,I_s,R,T_s,V,f1,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ;
fG1_II6 = G1_II6(Ea_R,F_out_s,I_o,I_s,R,T_s,V,f1,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ;
fG1_II7 = G1_II7 ;
fG1_II8 = G1_II8 ;
fG1_II9 = G1_II9(Ea_R,I_o,I_s,R,T_s,n_R_s,n_tot) ;
fG1k_II1 = conj(fG1_II1) ;
fG1k_II5 = conj(fG1_II5) ;
fG1k_II6 = conj(fG1_II6) ;
fG1k_II7 = conj(fG1_II7) ;
fG1k_II8 = conj(fG1_II8) ;
fG1k_II9 = conj(fG1_II9) ;

fG2crss10 = G2crss10(F_out_s,fG1_I1,fG1_I5,fG1_I6,fG1_I7,fG1_I8,fG1_I9,fG1k_II1,fG1k_II5,fG1k_II6,fG1k_II7,fG1k_II8,fG1k_II9,MF_A_s,R,T_s,V,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ; 

%% DC COMPONENT COMPUTATIONS

fDC_III10 = zeros(1,length(f1)) ;

for i = 1:length(f1)
    
fDC_III10(1,i) = DC_III10(Amp_1(1,i),Amp_2(1,i),Ea_R,F_out_s,fG1_I1(1,i),fG1_I5(1,i),fG1_I6(1,i),fG1_I7,fG1_I8,fG1_I9,fG1_II1(1,i),fG1_II5(1,i),fG1_II6(1,i),fG1_II7,fG1_II8,fG1_II9,fG1k_I1(1,i),fG1k_I5(1,i),fG1k_I6(1,i),fG1k_I7,fG1k_I8,fG1k_I9,fG1k_II1(1,i),fG1k_II5(1,i),fG1k_II6(1,i),fG1k_II7,fG1k_II8,fG1k_II9,I_o,I_s,MF_A_s,R,T_s,V,fi(1,i),k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ;

end

fG2aI10 = G2aI10(F_out_s,fG1_I1,fG1_I5,fG1_I6,fG1_I7,fG1_I8,fG1_I9,fG1k_I1,fG1k_I5,fG1k_I6,fG1k_I7,fG1k_I8,fG1k_I9,MF_A_s,R,T_s,V,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ;
           
fG2aII10 = G2aII10(Ea_R,F_out_s,fG1_II1,fG1_II5,fG1_II6,fG1_II7,fG1_II8,fG1_II9,fG1k_II1,fG1k_II5,fG1k_II6,fG1k_II7,fG1k_II8,fG1k_II9,I_o,I_s,MF_A_s,R,T_s,V,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ;

fG2star10 = H2star10(F_out_s,fG1_I1,fG1_I5,fG1_I6,fG1_I7,fG1_I8,fG1_I9,fG1k_II1,fG1k_II5,fG1k_II6,fG1k_II7,fG1k_II8,fG1k_II9,MF_A_s,R,T_s,V,fi,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ;

fDC_I10 = DC_I10(A1,F_out_s,fG1_I1,fG1_I5,fG1_I6,fG1_I7,fG1_I8,fG1_I9,fG1k_I1,fG1k_I5,fG1k_I6,fG1k_I7,fG1k_I8,fG1k_I9,MF_A_s,R,T_s,V,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ;
           
fDC_II10 = DC_II10(A2,Ea_R,F_out_s,fG1_II1,fG1_II5,fG1_II6,fG1_II7,fG1_II8,fG1_II9,fG1k_II1,fG1k_II5,fG1k_II6,fG1k_II7,fG1k_II8,fG1k_II9,I_o,I_s,MF_A_s,R,T_s,V,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ;

%% SYSTEM CRITERIA COMPUTATIONS

MF_out_I   = MF_A_s * ( 1 + fDC_I10(1,:) ) ;
MF_out_II  = MF_A_s * ( 1 + fDC_II10(1,:) ) ;
MF_out_III = MF_A_s * ( 1 + fDC_III10(1,:) ) ;
MF_out_ss  = linspace(MF_A_s,MF_A_s,length(f1)) ;

% Mean values for the outlet molar flow rates of A for change of inlet flow
% rate (I), light intensity (II), and both simultaneously (III):

MF_A_I_mean   = MF_A_s + MF_A_s .*   2 .* ( A1 ./ 2 ).^2 .* fG2aI10 ;
MF_A_II_mean  = MF_A_s + MF_A_s *                                2 .* ( A2 ./ 2 ).^2 .* fG2aII10 ;
MF_A_III_mean = MF_A_s + MF_A_s .* ( 2 .* ( A1 ./ 2 ).^2 .* fG2aI10 + 2 .* ( A2 ./ 2 ).^2 .* fG2aII10 + 2 .* ( A1 ./ 2 ) .* ( A2 ./ 2 ) .* ( cos(fi) .* real(fG2crss10) + sin(fi) .* imag(fG2crss10) ) ) ;

Conv_I   = ( MF_A_in - MF_A_I_mean  )  ./ MF_A_in * 100 ; 
Conv_II  = ( MF_A_in - MF_A_II_mean )  ./ MF_A_in * 100 ;
Conv_III = ( MF_A_in - MF_A_III_mean ) ./ MF_A_in * 100 ;

Conv_ss = linspace((MF_A_in-MF_A_s)/MF_A_in*100,(MF_A_in-MF_A_s)/MF_A_in*100,length(f1)) ;

of = real( MF_A_III_mean );
end