clf ; clear all; clc;
%% OPTIMISED STEADY STATE VALUES

T_s = 340 ;         
I_s = 4.3965 ;  

% SS CONVs   80        75          70          65         60
y_A_in =    [0.12212   0.153905    0.13857     0.152603    0.141664] ;
F_in   =    [4.966     4.171       4.983       4.876       5.682  ] * 1e-8 ;

%% OPTIMISATION INPUTS

f1 = logspace(-6,2,500) ;
 
%% OPTIMISATION, CONVERSION OBJECTIVE FUNCTION

lb2 = [0,   0,  0] ;
ub2 = [0.7, 1,  1] ;
ig2 = [0.5, 0.5, 0.5] ;
optionsga = optimoptions('fmincon', 'display', 'off', 'FunctionTolerance', 1e-4) ;

[Amp_1_cv_Fy, Amp_2_cv_Fy, fi_cv_Fy] = deal(zeros(length(F_in),length(f1))) ;

for j = 1:length(F_in)
    for i = 1:length(f1)

    x = fmincon(@(x)objFUN1(x, I_s, T_s, y_A_in(j), F_in(j), f1(1,i)), ig2,[],[],[],[],lb2,ub2,@(x)constraints1(x, I_s, T_s, y_A_in(j), F_in(j), f1(1,i)),optionsga) ;

    Amp_1_cv_Fy(j,i) = x(1) ;
    Amp_2_cv_Fy(j,i) = x(2) ;
    fi_cv_Fy(j,i)    = x(3) * 2*pi() ;

    end 
end
% FRF

[fG2aI10_cv_Fy, fG2aII10_cv_Fy, fG2star10_cv_Fy, Conv_I_cv_Fy, Conv_II_cv_Fy, Conv_III_cv_Fy, Conv_ss_cv_Fy, MF_A_in_cv_Fy, MF_A_III_mean_cv_Fy]...
    = deal(zeros(length(F_in),length(f1))) ;

for j = 1:length(F_in)
    for i = 1:length(f1)

    [fG2aI10_cv_Fy(j,i), fG2aII10_cv_Fy(j,i), fG2star10_cv_Fy(j,i), Conv_I_cv_Fy(j,i), Conv_II_cv_Fy(j,i), Conv_III_cv_Fy(j,i), Conv_ss_cv_Fy(j,i), MF_A_in_cv_Fy(j,i), MF_A_III_mean_cv_Fy(j,i)]...
            = combination11_sims(f1(1,i), fi_cv_Fy(j,i), Amp_1_cv_Fy(j,i), Amp_2_cv_Fy(j,i), I_s, T_s, y_A_in(j), F_in(j)) ;

    end
end
%% TABLE AND SAVE

[C_max, x_index] = max(Conv_III_cv_Fy,[],2) ;
C_SS             = Conv_ss_cv_Fy(1:5,1) ;
MF_A_in          = MF_A_in_cv_Fy(1:5,1) ;
RI               = (1-(C_SS(1:5,1) ./ C_max(1:5,1))) * 100 ;
Frequency        = f1(1,x_index(1:5,1))' ;
Amp_F            = Amp_1_cv_Fy(1:5,x_index(1:5,1)) ;  
Amp_y            = Amp_2_cv_Fy(1:5,x_index(1:5,1)) ;
PhaseDiff        = fi_cv_Fy(1:5,x_index(1:5,1)) ;
Amp_F = Amp_F(1:5,1) ;
Amp_y = Amp_y(1:5,1) ;
PhaseDiff    = PhaseDiff(1:5,1) ;

for j = length(F_in)
    
MF_A_III_mean(j,1) = real(MF_A_III_mean_cv_Fy(j,x_index(j))) ;



end
%%

TAB_Fy = table(C_max, C_SS, RI, MF_A_III_mean, MF_A_in, Frequency, Amp_F, Amp_y, PhaseDiff) ;
% save('NVARS_VALS_Fy') 

%% DIAGRAMS

% load('NVARS_VALS_Fy') 
figure (4)
subplot(3,1,1)
semilogx(f1,fG2aI10_cv_Fy,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('ASO FRFs')
legend('Inlet Volumetric Flow Rate')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{F}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,2)
semilogx(f1,fG2aII10_cv_Fy,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('ASO FRFs')
legend('Inlet Acid Molar Fraction')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{y_Ao}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,3)
semilogx(f1,fG2star10_cv_Fy,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('ASO Cross-Term')
legend('Flow and Molar Fraction')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)^*_{F, y_Ao}(\omega,-\omega)}, /')
box on
grid
%%
figure (5)
subplot(3,1,1)
no = 1 ;
semilogx(f1,smoothdata(Conv_I_cv_Fy(3,:)),'k','LineWidth',2)
hold on
semilogx(f1,smoothdata(Conv_II_cv_Fy(3,:)),'b','LineWidth',2)
semilogx(f1,Conv_ss_cv_Fy(3,:),'--r','LineWidth',2)
legend('Flow', 'Molar Fraction', 'Steady State')
title('Single Input Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,2)
semilogx(f1,Conv_II_cv_Fy(3,:),'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_cv_Fy,'--','LineWidth',2)
legend('Periodic, Molar Fraction', 'Steady State')
title('Single Input Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,3)
semilogx(f1,Conv_III_cv_Fy(3,:),'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_cv_Fy(3,:),'--','LineWidth',2)
legend('Periodic, Simultaneous', 'Steady State')
title('Flow and Molar Fraction Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion, %')
ylim([65 85])
box on
grid
%%
figure (6)
subplot(3,1,1)
yyaxis left
semilogx(f1,unwrap(fi_cv_Fy(3,:)),'LineWidth',2)
ylabel('Phase [rad]')
box on
yyaxis right
semilogx(f1, Amp_1_cv_Fy(3,:)*100, 'k', 'LineWidth',2)
hold on
semilogx(f1, Amp_2_cv_Fy(3,:)*100, '--r', 'LineWidth',2)
ylim([40 60])
legend('Phase Difference','Flow Amplitude', 'Molar Fraction Amplitude')
title('Optimal Periodic Variables')
xlabel('frequency, rad/s')
ylabel('Amplitude, %')
box on
grid

%% FUNCTIONS

% CONVERSION OBJECTIVE FUNCTION

function [of] = objFUN1(x, I_s, T_in, y_A_in, F_in, f1)
Amp_1 = x(1);
Amp_2 = x(2);
fi    = x(3) * 2*pi() ;

[~, ~, ~, ~, ~, Conv_III, ~, ~, ~]...
 = combination11_sims(f1, fi, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

of = (- Conv_III) ;
end
function [c, ceq] = constraints1(x, I_s, T_in, y_A_in, F_in, f1)
Amp_1 = x(1);
Amp_2 = x(2);
fi    = x(3) * 2*pi() ;

[~, ~, ~, ~, ~, Conv_III, ~, ~, ~]...
 = combination11_sims(f1, fi, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

c = [-Conv_III; Conv_III-100] ;
ceq = [] ;
end
