function [fG2aI10, fG2aII10, fG2star10, Conv_I, Conv_II, Conv_III, Conv_ss, MF_A_in, MF_A_III_mean] = combination11_sims(f1, fi, Amp_1, Amp_2, I_s, T_s, y_A_in, F_in)

%% OPERATING PARAMETER AND CONSTANT VALUES

T_in = T_s ;

p = 101325 ;
V = 2e-4 ;
n_tot = 0.0537 ;

% CONSTANTS

I_o = 1.6 ;

Ea_D1 = 113100 ;
Ea_D2 = 20920 ;
k_D1 = 1e13 ;
k_D2 = 2.05 ;

Ea_R = 8480 ;
k_R = 0.24 ;

k_Amp_1 = 1.503 ;
k_Amp_2 = 1.5e-5 ;
k_A3 = 32430 ;

R = 8.314 ;

%% STEADY-STATE VALUES COMPUTATION WITH EQUATIONS SUPPLIED BY TOM ELLWOOD

k_ads_s =   k_Amp_1 + k_Amp_2 .* exp (  k_A3 ./ R ./ T_in);
k_des_s =   k_D1 .* exp (- Ea_D1 ./ R ./ T_in) + k_D2 .* exp (- Ea_D2  ./ R ./ T_in);
n_R_s   =   n_tot .* exp (- Ea_R  ./ R ./ T_in) .* (I_s ./ I_o).^ 0.3; 

y_A_s   =  -(F_in*R*T_in*k_des_s*n_tot - (F_in^2*R^2*T_in^2*k_R^2*n_R_s^2 + 2*F_in^2*R^2*T_in^2*k_des_s*k_R*n_R_s*n_tot + F_in^2*R^2*T_in^2*k_des_s^2*n_tot^2 + 2*F_in*R^2*T_in*T_in*V*k_ads_s*k_R^2*n_R_s^2*n_tot + 2*F_in*R^2*T_in*T_in*V*k_ads_s*k_des_s*k_R*n_R_s*n_tot^2 + R^2*T_in^2*V^2*k_ads_s^2*k_R^2*n_R_s^2*n_tot^2 ...
            + 2*F_in^2*p*R*T_in*k_ads_s*k_R*n_R_s*n_tot*y_A_in + 4*F_in*R^2*T_in*T_in*V*k_ads_s*k_R^2*n_R_s^2*n_tot*y_A_in + 2*F_in^2*p*R*T_in*k_ads_s*k_des_s*n_tot^2*y_A_in + 4*F_in*R^2*T_in*T_in*V*k_ads_s*k_des_s*k_R*n_R_s*n_tot^2*y_A_in - 2*F_in*p*R*T_in*V*k_ads_s^2*k_R*n_R_s*n_tot^2*y_A_in + F_in^2*p^2*k_ads_s^2*n_tot^2*y_A_in^2)^(1/2) + F_in*R*T_in*k_R*n_R_s - F_in*p*k_ads_s*n_tot*y_A_in + R*T_in*V*k_ads_s*k_R*n_R_s*n_tot)/(2*(F_in*p*k_ads_s*n_tot + R*T_in*V*k_ads_s*k_R*n_R_s*n_tot));
 
theta_A_s = (p*k_ads_s*y_A_s)/(R*T_in*(k_des_s + (k_R*n_R_s)/n_tot + (p*k_ads_s*y_A_s)/(R*T_in)));
F_out_s   = V*(T_in./T_in .* F_in./V - k_ads_s .*n_tot * (1-theta_A_s) .* y_A_s + R* T_in/p * k_des_s .* theta_A_s * n_tot + 2*R.*T_in/p * k_R   .* n_R_s    .* theta_A_s   );

MF_A_s  = F_out_s * y_A_s  *p / R /T_s ;

%% FRFs COMPUTATION
         
fG1_I1  = G1_I1(F_in,F_out_s,R,T_s,T_in,T_in,V,f1,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,p,theta_A_s,y_A_s,y_A_in) ;
fG1_I5  = G1_I5(F_in,F_out_s,R,T_s,T_in,T_in,V,f1,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,p,theta_A_s,y_A_s,y_A_in) ;
fG1_I6  = G1_I6(F_in,F_out_s,R,T_s,T_in,T_in,V,f1,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,p,theta_A_s,y_A_s,y_A_in) ;
fG1_I7  = G1_I7 ;
fG1_I8  = G1_I8 ;
fG1_I9  = G1_I9 ;
fG1k_I1 = conj(fG1_I1) ;
fG1k_I5 = conj(fG1_I5) ;
fG1k_I6 = conj(fG1_I6) ;
fG1k_I7 = conj(fG1_I7) ;
fG1k_I8 = conj(fG1_I8) ;
fG1k_I9 = conj(fG1_I9) ;
fG1_II1 = G1_II1(F_in,F_out_s,R,T_s,T_in,V,f1,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,p,theta_A_s,y_A_s,y_A_in) ;
fG1_II5 = G1_II5(F_in,F_out_s,R,T_s,T_in,V,f1,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,p,theta_A_s,y_A_s,y_A_in) ;
fG1_II6 = G1_II6(F_in,F_out_s,R,T_s,T_in,V,f1,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,p,theta_A_s,y_A_s,y_A_in) ;
fG1_II7 = G1_II7 ;
fG1_II8 = G1_II8 ;
fG1_II9 = G1_II9 ;
fG1k_II1 = conj(fG1_II1) ;
fG1k_II5 = conj(fG1_II5) ;
fG1k_II6 = conj(fG1_II6) ;
fG1k_II7 = conj(fG1_II7) ;
fG1k_II8 = conj(fG1_II8) ;
fG1k_II9 = conj(fG1_II9) ;

fG2crss10 = G2crss10(F_in,F_out_s,fG1_I1,fG1_I5,fG1_I6,fG1_I7,fG1_I8,fG1_I9,fG1k_II1,fG1k_II5,fG1k_II6,fG1k_II7,fG1k_II8,fG1k_II9,MF_A_s,R,T_s,T_in,V,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,p,theta_A_s,y_A_s,y_A_in) ; 

%% DC COMPONENT COMPUTATIONS
    
fDC_III10 = DC_III10(Amp_1,Amp_2,F_in,F_out_s,fG1_I1,fG1_I5,fG1_I6,fG1_I7,fG1_I8,fG1_I9,fG1_II1,fG1_II5,fG1_II6,fG1_II7,fG1_II8,fG1_II9,fG1k_I1,fG1k_I5,fG1k_I6,fG1k_I7,fG1k_I8,fG1k_I9,fG1k_II1,fG1k_II5,fG1k_II6,fG1k_II7,fG1k_II8,fG1k_II9,MF_A_s,R,T_s,T_in,V,fi,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,p,theta_A_s,y_A_s,y_A_in) ;

fG2aI10 = G2aI10(F_out_s,fG1_I1,fG1_I5,fG1_I6,fG1_I7,fG1_I8,fG1_I9,fG1k_I1,fG1k_I5,fG1k_I6,fG1k_I7,fG1k_I8,fG1k_I9,MF_A_s,R,T_s,V,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ;
           
fG2aII10 = G2aII10(F_out_s,fG1_II1,fG1_II5,fG1_II6,fG1_II7,fG1_II8,fG1_II9,fG1k_II1,fG1k_II5,fG1k_II6,fG1k_II7,fG1k_II8,fG1k_II9,MF_A_s,R,T_s,V,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ;

fG2star10 = H2star10(F_in,F_out_s,fG1_I1,fG1_I5,fG1_I6,fG1_I7,fG1_I8,fG1_I9,fG1k_II1,fG1k_II5,fG1k_II6,fG1k_II7,fG1k_II8,fG1k_II9,MF_A_s,R,T_s,T_in,V,fi,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,p,theta_A_s,y_A_s,y_A_in) ;

fDC_I10 = DC_I10(Amp_1,F_out_s,fG1_I1,fG1_I5,fG1_I6,fG1_I7,fG1_I8,fG1_I9,fG1k_I1,fG1k_I5,fG1k_I6,fG1k_I7,fG1k_I8,fG1k_I9,MF_A_s,R,T_s,V,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ;
           
fDC_II10 = DC_II10(Amp_2,F_out_s,fG1_II1,fG1_II5,fG1_II6,fG1_II7,fG1_II8,fG1_II9,fG1k_II1,fG1k_II5,fG1k_II6,fG1k_II7,fG1k_II8,fG1k_II9,MF_A_s,R,T_s,V,k_R,k_ads_s,k_des_s,n_R_s,n_tot,p,theta_A_s,y_A_s) ;

%% SYSTEM CRITERIA COMPUTATIONS

MF_out_ss  = linspace(MF_A_s,MF_A_s,length(f1)) ;

MF_A_in   = real(F_in * y_A_in * ( 1 + 2 * Amp_1/2 * Amp_2/2 * cos(fi) ) * p/R/T_in ) ; % inlet molar flow rate in two-input periodic operation
MF_A_in_s = F_in * y_A_in                                     * p/R/T_in ; % inlet molar flow rate in single-input periodic operation and steady-state

% Mean values for the outlet molar flow rates of A for change of inlet flow
% rate (I), molar fraction (II), and both simultaneously (III):

MF_A_I_mean   = MF_A_s + MF_A_s *   2 * ( Amp_1 / 2 )^2 * fG2aI10 ;
MF_A_II_mean  = MF_A_s + MF_A_s *                                2 * ( Amp_2 / 2 )^2 * fG2aII10 ;
MF_A_III_mean = MF_A_s + MF_A_s * ( 2 * ( Amp_1 / 2 )^2 * fG2aI10 + 2 * ( Amp_2 / 2 )^2 * fG2aII10 + 2 * ( Amp_1 / 2 ) * ( Amp_2 / 2 ) * ( cos(fi) .* real(fG2crss10) + sin(fi) .* imag(fG2crss10) ) ) ;

Conv_I   = real( ( MF_A_in_s - MF_A_I_mean  )  ./ MF_A_in_s * 100 ) ; 
Conv_II  = real( ( MF_A_in_s - MF_A_II_mean )  ./ MF_A_in_s * 100 ) ;
Conv_III = real( ( MF_A_in   - MF_A_III_mean ) ./ MF_A_in   * 100 ) ;

Conv_ss  = linspace((MF_A_in_s-MF_A_s)/MF_A_in_s*100,(MF_A_in_s-MF_A_s)/MF_A_in_s*100,length(f1)) ;

end