clear all; clc;
%% LOADING OPTIMISED STEADY STATE VALUES

T_in = 340 ;    
I_s = 4.3965 ; 

% SS CONVs   80        75          70          65         60
y_A_in =    [0.12212   0.153905    0.13857     0.152603    0.141664] ;
F_in   =    [4.966     4.171       4.983       4.876       5.682  ] * 1e-8 ;

%% OPTIMISATION INPUTS

f1 = logspace(-6,2,500) ;
lb = [0   , 0] ;
ub = [1 , 1] ;
ig = [0.6, 0.6] ;
optionsga = optimoptions('fmincon', 'display', 'off', 'FunctionTolerance', 1e-4) ;

%% OPTIMISATION MAX CONVERSION OF ACID

[Amp_1_mfo_yI, Amp_2_mfo_yI, fi_mfo_yI] = deal(zeros(length(F_in),length(f1))) ;

for j = 1:length(F_in)
    for i = 1:length(f1)
    x = fmincon(@(x)objFUN(x, I_s, T_in, y_A_in(j), F_in(j), f1(1,i)), ig,[],[],[],[],lb,ub,@(x)constraints(x, I_s, T_in, y_A_in(j), F_in(j), f1(1,i)),optionsga) ;

    Amp_1_mfo_yI(j,i) = x(1);
    Amp_2_mfo_yI(j,i) = x(2);
    end    
end

[fG2aI10_mfo_yI, fG2aII10_mfo_yI, fG2star10_mfo_yI, Conv_I_mfo_yI, Conv_II_mfo_yI, Conv_III_mfo_yI, Conv_ss_mfo_yI, MF_A_in_mfo_yI, MF_out_I_mfo_yI, MF_out_II_mfo_yI, MF_out_III_mfo_yI]...
    = deal(zeros(length(F_in),length(fi))) ;

for j = 1:length(F_in)
    for i = 1:length(f1) 
    [fi_mfo_yI(j,i), fG2aI10_mfo_yI(j,i), fG2aII10_mfo_yI(j,i), fG2star10_mfo_yI(j,i), Conv_I_mfo_yI(j,i), Conv_II_mfo_yI(j,i), Conv_III_mfo_yI(j,i), Conv_ss_mfo_yI(j,i), MF_A_in_mfo_yI(j,i), MF_out_I_mfo_yI(j,i), MF_out_II_mfo_yI(j,i), MF_out_III_mfo_yI(j,i)]...
            = combination4_sims(f1(1,i), Amp_1_mfo_yI(j,i), Amp_2_mfo_yI(j,i), I_s, T_in, y_A_in(j), F_in(j)) ;  
    end
end

%% TABLE AND SAVE

[C_max, x_index] = max(Conv_III_mfo_yI,[],2) ;
C_SS             = Conv_ss_mfo_yI(1:5,1) ;
MF_A_in          = MF_A_in_mfo_yI(1:5,1) ;
RI               = (1-(C_SS(1:5,1) ./ C_max(1:5,1))) * 100 ;
Frequency        = f1(1,x_index(1:5,1))' ;
Amp_y            = Amp_1_mfo_yI(1:5,x_index(1:5,1)) ;  
Amp_I            = Amp_2_mfo_yI(1:5,x_index(1:5,1)) ;
PhaseDiff        = fi_mfo_yI(1:5,x_index(1:5,1)) ;
Amp_y = Amp_y(1:5,1) ;
Amp_I = Amp_I(1:5,1) ;
PhaseDiff    = PhaseDiff(1:5,1) ;

for j = length(F_in)
    
MF_A_III_mean(j,1) = real(MF_out_III_mfo_yI(j,x_index(j))) ;

end
%%

TAB_yI = table(C_max, C_SS, RI, MF_A_III_mean, MF_A_in, Frequency, Amp_y, Amp_I, PhaseDiff) ;
save('NVARS_VALS_yI') 


%% DIAGRAMS

% load('NVARS_VALS_yI')

figure (2)
subplot(3,1,1)
semilogx(f1,fG2aI10_mfo_yI,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('ASO FRFs')
legend('Inlet Acid Molar Fraction')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{T}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,2)
semilogx(f1,fG2aII10_mfo_yI,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('ASO FRFs')
legend('Light Intensity')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{y_Ao}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,3)
semilogx(f1,fG2star10_mfo_yI,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('ASO Cross-Term')
legend('Molar Fraction and Light Intensity')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)^*_{T, y_Ao}(\omega,-\omega)}, /')
box on
grid
%%
figure (3)
subplot(3,1,1)
semilogx(f1,Conv_I_mfo_yI,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_yI,'--','LineWidth',2)
legend('Periodic, Molar Fraction', 'Steady State')
title('Single Input Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,2)
semilogx(f1,Conv_II_mfo_yI,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_yI,'--','LineWidth',2)
legend('Periodic, Light Intensity', 'Steady State')
title('Single Input Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,3)
semilogx(f1,Conv_III_mfo_yI,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_yI,'--','LineWidth',2)
legend('Periodic, Simultaneous', 'Steady State')
title('Molar Fraction and Light Intensity Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
%%
figure (5)
subplot(3,1,1)
yyaxis left
semilogx(f1,unwrap(fi_mfo_yI),'LineWidth',2)
ylabel('Phase [rad]')
box on
yyaxis right
semilogx(f1, Amp_1_mfo_yI*100, '--k', 'LineWidth',2)
hold on
semilogx(f1, Amp_2_mfo_yI*100, '--r', 'LineWidth',2)
ylim([0 60])
legend('Phase Difference', 'Molar Fraction Amplitude','Light Intensity Amplitude')
title('Optimal Periodic Variables')
xlabel('frequency, rad/s')
ylabel('Amplitude, %')
box on
grid

% figure (2)
% subplot(3,1,1)
% semilogx(f1,fG2aI10_mfo_yI,'k','LineWidth',2)
% hold on
% title('ASO FRF Molar Fraction')
% xlabel('frequency, rad/s')
% ylabel('\it{G^(^2^)_{T}(\omega,-\omega)}, /')
% box on
% grid
% subplot(3,1,2)
% semilogx(f1,fG2aII10_mfo_yI,'k','LineWidth',2)
% hold on
% title('ASO FRF Light Intensity')
% xlabel('frequency, rad/s')
% ylabel('\it{G^(^2^)_{I}(\omega,-\omega)}, /')
% box on
% grid
% subplot(3,1,3)
% semilogx(f1,fG2star10_mfo_yI,'k','LineWidth',2)
% title('ASO Cross-Term Flow and Light Intensity')
% xlabel('frequency, rad/s')
% ylabel('\it{G^(^2^)^*_{T, I}(\omega,-\omega)}, /')
% box on
% grid
% 
% 
% figure (3)
% subplot(3,1,1)
% semilogx(f1,Conv_I_mfo_yI,'k','LineWidth',2)
% hold on
% semilogx(f1,Conv_ss_mfo_yI,'--','LineWidth',2)
% legend('Periodic', 'Steady State')
% title('Molar Fraction Modulation')
% xlabel('frequency, rad/s')
% ylabel('Conversion')
% box on
% grid
% subplot(3,1,2)
% semilogx(f1,Conv_II_mfo_yI,'k','LineWidth',2)
% hold on
% semilogx(f1,Conv_ss_mfo_yI,'--','LineWidth',2)
% legend('Periodic', 'Steady State')
% title('Light Intensity Modulation')
% xlabel('frequency, rad/s')
% ylabel('Conversion')
% box on
% grid
% subplot(3,1,3)
% semilogx(f1,Conv_III_mfo_yI,'k','LineWidth',2)
% hold on
% semilogx(f1,Conv_ss_mfo_yI,'--','LineWidth',2)
% ylim([69.5, 70.5])
% legend('Periodic', 'Steady State')
% title('Combined Modulation')
% xlabel('frequency, rad/s')
% ylabel('Conversion')
% box on
% grid
% 
% figure (5)
% subplot(3,1,1)
% semilogx(f1,fi_mfo_yI,'k','LineWidth',1)
% hold on
% title('Optimal Phase Difference For Minimum Molar Flow Out')
% xlabel('frequency, rad/s')
% ylabel('Phase [rad]')
% box on
% grid
% subplot(3,1,2)
% semilogx(f1, Amp_1_mfo_yI*100, 'k', 'LineWidth',1)
% hold on
% semilogx(f1, Amp_2_mfo_yI*100, 'r', 'LineWidth',1)
% legend('Molar Fraction Amplitude', 'Light Intensity Amplitude')
% title('Optimal Amplitudes For Minimum Molar Flow Out')
% xlabel('frequency, rad/s')
% ylabel('Amplitude, %')
% box on
% grid



%% FUNCTIONS

function [of1] = objFUN(x, I_s, T_in, y_A_in, F_in, f1)
Amp_1 = x(1);
Amp_2 = x(2);

[~, ~, ~, ~, ~, ~, Conv_III, ~, ~, ~, ~, MF_out_III]...
 = combination4_sims(f1, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

of1 = (MF_out_III) ;
of2 = (Conv_III) ;
end
function [c, ceq] = constraints(x, I_s, T_in, y_A_in, F_in, f1)
Amp_1 = x(1);
Amp_2 = x(2);

[~, ~, ~, ~, ~, ~, Conv_III, ~, ~, ~, ~, MF_out_III]...
 = combination4_sims(f1, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

c = [-Conv_III; Conv_III-100] ;
ceq = [] ;
end
