clear all; clc;
%% LOADING OPTIMISED STEADY STATE VALUES

T_in = 340 ;         
I_s = 4.3965 ;      

% SS CONVs   80        75          70          65         60
y_A_in =    [0.12212   0.153905    0.13857     0.152603    0.141664] ;
F_in   =    [4.966     4.171       4.983       4.876       5.682  ] * 1e-8 ;

%% OPTIMISATION INPUTS

f1 = logspace(-6, 2, 500) ;
lb = [0,      0] ;
ub = [20/T_in, 1] ;
ig = [0.01,  0.9] ;
optionsga = optimoptions('fmincon', 'display', 'off', 'FunctionTolerance', 1e-4) ;

%% OPTIMISATION MAX CONVERSION OF ACID

[Amp_1_mfo_TI, Amp_2_mfo_TI] = deal(zeros(length(F_in),length(f1))) ;

for j = 1:length(F_in)
    for i = 1:length(f1)
    x = fmincon(@(x)objFUN(x, I_s, T_in, y_A_in(j), F_in(j), f1(1,i)), ig,[],[],[],[],lb,ub,@(x)constraints(x, I_s, T_in, y_A_in(j), F_in(j), f1(1,i)),optionsga) ;

    Amp_1_mfo_TI(j,i) = x(1);
    Amp_2_mfo_TI(j,i) = x(2);
    end    
end

[fi_mfo_TI, fG2aI10_mfo_TI, fG2aII10_mfo_TI, fG2star10_mfo_TI, Conv_I_mfo_TI, Conv_II_mfo_TI, Conv_III_mfo_TI, Conv_ss_mfo_TI, MF_A_in_mfo_TI, MF_out_I_mfo_TI, MF_out_II_mfo_TI, MF_out_III_mfo_TI]...
    = deal(zeros(length(F_in),length(fi))) ;

for j = 1:length(F_in)
    for i = 1:length(f1)     
    [fi_mfo_TI(j,i), fG2aI10_mfo_TI(j,i), fG2aII10_mfo_TI(j,i), fG2star10_mfo_TI(j,i), Conv_I_mfo_TI(j,i), Conv_II_mfo_TI(j,i), Conv_III_mfo_TI(j,i), Conv_ss_mfo_TI(j,i), MF_A_in_mfo_TI(j,i), MF_out_I_mfo_TI(j,i), MF_out_II_mfo_TI(j,i), MF_out_III_mfo_TI(j,i)]...
            = combination2_sims(f1(1,i), Amp_1_mfo_TI(j,i), Amp_2_mfo_TI(j,i), I_s, T_in, y_A_in(j), F_in(j)) ;  
    end
end

%% TABLE AND SAVE

[C_max, x_index] = max(Conv_III_mfo_TI,[],2) ;
C_SS             = Conv_ss_mfo_TI(1:5,1) ;
MF_A_in          = MF_A_in_mfo_TI(1:5,1) ;
RI               = (1-(C_SS(1:5,1) ./ C_max(1:5,1))) * 100 ;
Frequency        = f1(1,x_index(1:5,1))' ;
Amp_T            = Amp_1_mfo_TI(1:5,x_index(1:5,1)) ;  
Amp_I            = Amp_2_mfo_TI(1:5,x_index(1:5,1)) ;
PhaseDiff        = fi_mfo_TI(1:5,x_index(1:5,1)) ;
Amp_T = Amp_T(1:5,1) ;
Amp_I = Amp_I(1:5,1) ;
PhaseDiff    = PhaseDiff(1:5,1) ;

for j = length(F_in)
    
MF_A_III_mean(j,1) = real(MF_out_III_mfo_TI(j,x_index(j))) ;

end

[C_maxT, x_indexT] = max(Conv_I_mfo_TI,[],2) ;
C_SST             = Conv_ss_mfo_TI(1:5,1) ;
MF_A_inT          = MF_A_in_mfo_TI(1:5,1) ;
RIT               = (1-(C_SST(1:5,1) ./ C_maxT(1:5,1))) * 100 ;
FrequencyT        = f1(1,x_indexT(1:5,1))' ;

%%

TAB_TI = table(C_max, C_SS, RI, MF_A_III_mean, MF_A_in, Frequency, Amp_T, Amp_I, PhaseDiff) ;
TAB_T  = table(C_maxT, C_SST, RIT, MF_A_inT, FrequencyT) ;
save('NVARS_VALS_TI') 

%% DIAGRAMS
load('NVARS_VALS_TI')
%%
figure (4)
subplot(3,1,1)
semilogx(f1,fG2aI10_mfo_TI,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('ASO FRFs')
legend('Temperature')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{T}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,2)
semilogx(f1,fG2aII10_mfo_TI,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('ASO FRFs')
legend('Light Intensity')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{I}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,3)
semilogx(f1,fG2star10_mfo_TI,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('ASO Cross-Term')
legend('Temperature and Light Intensity')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)^*_{T, I}(\omega,-\omega)}, /')
box on
grid
%%
figure (5)
subplot(3,1,1)
no = 4 ;
semilogx(f1,Conv_I_mfo_TI(no,:),'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_TI(no,:),'--','LineWidth',2)
legend('Periodic, Temperature', 'Steady State')
title('Single Input Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,2)
semilogx(f1,Conv_II_mfo_TI,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_TI,'--','LineWidth',2)
legend('Periodic, Light Intensity', 'Steady State')
title('Single Input Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,3)
semilogx(f1,Conv_III_mfo_TI,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_TI,'--','LineWidth',2)
legend('Periodic, Simultaneous', 'Steady State')
title('Temperature and Light Intensity')
xlabel('frequency, rad/s')
ylabel('Conversion, %')
ylim([50 100])
box on
grid
%%
figure (6)
subplot(3,1,1)
yyaxis left
semilogx(f1,unwrap(fi_mfo_TI),'LineWidth',2)
ylabel('Phase [rad]')
box on
yyaxis right
semilogx(f1, Amp_1_mfo_TI*100, '--k', 'LineWidth',2)
hold on
semilogx(f1, Amp_2_mfo_TI*100, '--r', 'LineWidth',2)
% ylim([0 60])
legend('Phase Difference','Temperature Amplitude', 'Light Intensity Amplitude')
title('Optimal Periodic Variables')
xlabel('frequency, rad/s')
ylabel('Amplitude, %')
box on
grid



%% FUNCTIONS

function [of] = objFUN(x, I_s,T_in,y_A_in, F_in, f1)
Amp_1 = x(1);
Amp_2 = x(2);

[~,~, ~, ~, ~, ~, ~, ~, ~, ~, ~, MF_A_III_mean]...
 = combination2_sims(f1, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

of = (MF_A_III_mean) ;
end
function [c, ceq] = constraints(x, I_s, T_in, y_A_in, F_in, f1)
Amp_1 = x(1);
Amp_2 = x(2);

[~,~, ~, ~, ~, ~, Conv_III, ~, ~, ~, ~, ~]...
 = combination2_sims(f1, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

c = [-Conv_III; Conv_III-100] ;
ceq = [] ;
end